@@ -142,6 +142,8 @@ class TheOneRingConnection(
 		self._delayedConnect = gobject_utils.Async(self._delayed_connect)
 
 		_moduleLogger.info("Connection to the account %s created" % account)
+		self._timedDisconnect = autogv.TimedDisconnect(weakref.ref(self))
+		self._timedDisconnect.start()
 
 	@property
 	def manager(self):
@@ -166,11 +168,9 @@ class TheOneRingConnection(
 	def get_handle_by_name(self, handleType, handleName):
 		requestedHandleName = handleName.encode('utf-8')
 		if handleType == telepathy.HANDLE_TYPE_CONTACT:
-			_moduleLogger.debug("get_handle_by_name Contact: %s" % requestedHandleName)
 			h = handle.create_handle(self, 'contact', requestedHandleName)
 		elif handleType == telepathy.HANDLE_TYPE_LIST:
 			# Support only server side (immutable) lists
-			_moduleLogger.debug("get_handle_by_name List: %s" % requestedHandleName)
 			h = handle.create_handle(self, 'list', requestedHandleName)
 		else:
 			raise telepathy.errors.NotAvailable('Handle type unsupported %d' % handleType)
@@ -190,6 +190,7 @@ class TheOneRingConnection(
 			return
 		_moduleLogger.info("Kicking off connect")
 		self._delayedConnect.start()
+		self._timedDisconnect.stop()
 
 	@misc_utils.log_exception(_moduleLogger)
 	def _delayed_connect(self):
@@ -281,6 +282,7 @@ class TheOneRingConnection(
 		_moduleLogger.info("Disconnecting")
 
 		self._delayedConnect.cancel()
+		self._timedDisconnect.stop()
 
 		# Not having the disconnect first can cause weird behavior with clients
 		# including not being able to reconnect or even crashing
